""" Contains shared errors types that can be raised from API functions """


class UnexpectedStatus(Exception):
    """Raised by api functions when the response status an undocumented status and Client.raise_on_unexpected_status is True"""

    ...


__all__ = ["UnexpectedStatus"]



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_network_interface_network_interface_ethernet_port_list_ethernet_port import (
        RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort,
    )


T = TypeVar("T", bound="RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList")


@attr.s(auto_attribs=True)
class RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList:
    """
    Attributes:
        ethernet_port (Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort]):
        size (Union[Unset, str]):
    """

    ethernet_port: Union[Unset, "RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort"] = UNSET
    size: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ethernet_port: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ethernet_port, Unset):
            ethernet_port = self.ethernet_port.to_dict()

        size = self.size

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ethernet_port is not UNSET:
            field_dict["EthernetPort"] = ethernet_port
        if size is not UNSET:
            field_dict["@size"] = size

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_network_interface_network_interface_ethernet_port_list_ethernet_port import (
            RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort,
        )

        d = src_dict.copy()
        _ethernet_port = d.pop("EthernetPort", UNSET)
        ethernet_port: Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort]
        if isinstance(_ethernet_port, Unset):
            ethernet_port = UNSET
        else:
            ethernet_port = RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort.from_dict(
                _ethernet_port
            )

        size = d.pop("@size", UNSET)

        root_type_for_xml_network_interface_network_interface_ethernet_port_list = cls(
            ethernet_port=ethernet_port,
            size=size,
        )

        root_type_for_xml_network_interface_network_interface_ethernet_port_list.additional_properties = d
        return root_type_for_xml_network_interface_network_interface_ethernet_port_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_session_login_cap_session_login_cap import (
        RootTypeForXMLSessionLoginCapSessionLoginCap,
    )


T = TypeVar("T", bound="RootTypeForXMLSessionLoginCap")


@attr.s(auto_attribs=True)
class RootTypeForXMLSessionLoginCap:
    """
    Example:
        {'SessionLoginCap': {'sessionID': '5ab522a707187090e375dc9e07f80f48f6a2a1c4a171b501b47ea9607db57f7f',
            'challenge': '3f559d75aa0c053e631092d75aa59355', 'iterations': '100', 'isIrreversible': 'true', 'salt':
            'ADX8O3PD524FJ1BGFXK7X94SXKU1G3VQGSYKBOXW61S5IJLYWM59B9289WPPFKFV', 'sessionIDVersion': '2', '@version': '2.0',
            '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        session_login_cap (Union[Unset, RootTypeForXMLSessionLoginCapSessionLoginCap]):
    """

    session_login_cap: Union[Unset, "RootTypeForXMLSessionLoginCapSessionLoginCap"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        session_login_cap: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.session_login_cap, Unset):
            session_login_cap = self.session_login_cap.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if session_login_cap is not UNSET:
            field_dict["SessionLoginCap"] = session_login_cap

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_session_login_cap_session_login_cap import (
            RootTypeForXMLSessionLoginCapSessionLoginCap,
        )

        d = src_dict.copy()
        _session_login_cap = d.pop("SessionLoginCap", UNSET)
        session_login_cap: Union[Unset, RootTypeForXMLSessionLoginCapSessionLoginCap]
        if isinstance(_session_login_cap, Unset):
            session_login_cap = UNSET
        else:
            session_login_cap = RootTypeForXMLSessionLoginCapSessionLoginCap.from_dict(_session_login_cap)

        root_type_for_xml_session_login_cap = cls(
            session_login_cap=session_login_cap,
        )

        root_type_for_xml_session_login_cap.additional_properties = d
        return root_type_for_xml_session_login_cap

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RootTypeForXMLStreamingChannelVideo")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelVideo:
    """
    Attributes:
        enabled (Union[Unset, str]):
        video_input_channel_id (Union[Unset, str]):
        video_codec_type (Union[Unset, str]):
        video_scan_type (Union[Unset, str]):
        video_resolution_width (Union[Unset, str]):
        video_resolution_height (Union[Unset, str]):
        video_quality_control_type (Union[Unset, str]):
        constant_bit_rate (Union[Unset, str]):
        fixed_quality (Union[Unset, str]):
        vbr_upper_cap (Union[Unset, str]):
        vbr_lower_cap (Union[Unset, str]):
        max_frame_rate (Union[Unset, str]):
        key_frame_interval (Union[Unset, str]):
        snap_shot_image_type (Union[Unset, str]):
        gov_length (Union[Unset, str]):
    """

    enabled: Union[Unset, str] = UNSET
    video_input_channel_id: Union[Unset, str] = UNSET
    video_codec_type: Union[Unset, str] = UNSET
    video_scan_type: Union[Unset, str] = UNSET
    video_resolution_width: Union[Unset, str] = UNSET
    video_resolution_height: Union[Unset, str] = UNSET
    video_quality_control_type: Union[Unset, str] = UNSET
    constant_bit_rate: Union[Unset, str] = UNSET
    fixed_quality: Union[Unset, str] = UNSET
    vbr_upper_cap: Union[Unset, str] = UNSET
    vbr_lower_cap: Union[Unset, str] = UNSET
    max_frame_rate: Union[Unset, str] = UNSET
    key_frame_interval: Union[Unset, str] = UNSET
    snap_shot_image_type: Union[Unset, str] = UNSET
    gov_length: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        video_input_channel_id = self.video_input_channel_id
        video_codec_type = self.video_codec_type
        video_scan_type = self.video_scan_type
        video_resolution_width = self.video_resolution_width
        video_resolution_height = self.video_resolution_height
        video_quality_control_type = self.video_quality_control_type
        constant_bit_rate = self.constant_bit_rate
        fixed_quality = self.fixed_quality
        vbr_upper_cap = self.vbr_upper_cap
        vbr_lower_cap = self.vbr_lower_cap
        max_frame_rate = self.max_frame_rate
        key_frame_interval = self.key_frame_interval
        snap_shot_image_type = self.snap_shot_image_type
        gov_length = self.gov_length

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if video_input_channel_id is not UNSET:
            field_dict["videoInputChannelID"] = video_input_channel_id
        if video_codec_type is not UNSET:
            field_dict["videoCodecType"] = video_codec_type
        if video_scan_type is not UNSET:
            field_dict["videoScanType"] = video_scan_type
        if video_resolution_width is not UNSET:
            field_dict["videoResolutionWidth"] = video_resolution_width
        if video_resolution_height is not UNSET:
            field_dict["videoResolutionHeight"] = video_resolution_height
        if video_quality_control_type is not UNSET:
            field_dict["videoQualityControlType"] = video_quality_control_type
        if constant_bit_rate is not UNSET:
            field_dict["constantBitRate"] = constant_bit_rate
        if fixed_quality is not UNSET:
            field_dict["fixedQuality"] = fixed_quality
        if vbr_upper_cap is not UNSET:
            field_dict["vbrUpperCap"] = vbr_upper_cap
        if vbr_lower_cap is not UNSET:
            field_dict["vbrLowerCap"] = vbr_lower_cap
        if max_frame_rate is not UNSET:
            field_dict["maxFrameRate"] = max_frame_rate
        if key_frame_interval is not UNSET:
            field_dict["keyFrameInterval"] = key_frame_interval
        if snap_shot_image_type is not UNSET:
            field_dict["snapShotImageType"] = snap_shot_image_type
        if gov_length is not UNSET:
            field_dict["GovLength"] = gov_length

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        enabled = d.pop("enabled", UNSET)

        video_input_channel_id = d.pop("videoInputChannelID", UNSET)

        video_codec_type = d.pop("videoCodecType", UNSET)

        video_scan_type = d.pop("videoScanType", UNSET)

        video_resolution_width = d.pop("videoResolutionWidth", UNSET)

        video_resolution_height = d.pop("videoResolutionHeight", UNSET)

        video_quality_control_type = d.pop("videoQualityControlType", UNSET)

        constant_bit_rate = d.pop("constantBitRate", UNSET)

        fixed_quality = d.pop("fixedQuality", UNSET)

        vbr_upper_cap = d.pop("vbrUpperCap", UNSET)

        vbr_lower_cap = d.pop("vbrLowerCap", UNSET)

        max_frame_rate = d.pop("maxFrameRate", UNSET)

        key_frame_interval = d.pop("keyFrameInterval", UNSET)

        snap_shot_image_type = d.pop("snapShotImageType", UNSET)

        gov_length = d.pop("GovLength", UNSET)

        root_type_for_xml_streaming_channel_video = cls(
            enabled=enabled,
            video_input_channel_id=video_input_channel_id,
            video_codec_type=video_codec_type,
            video_scan_type=video_scan_type,
            video_resolution_width=video_resolution_width,
            video_resolution_height=video_resolution_height,
            video_quality_control_type=video_quality_control_type,
            constant_bit_rate=constant_bit_rate,
            fixed_quality=fixed_quality,
            vbr_upper_cap=vbr_upper_cap,
            vbr_lower_cap=vbr_lower_cap,
            max_frame_rate=max_frame_rate,
            key_frame_interval=key_frame_interval,
            snap_shot_image_type=snap_shot_image_type,
            gov_length=gov_length,
        )

        root_type_for_xml_streaming_channel_video.additional_properties = d
        return root_type_for_xml_streaming_channel_video

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx
import xmltodict

from ... import errors
from ...client import Client
from ...models.root_type_for_xml_device_info import RootTypeForXMLDeviceInfo
from ...models.root_type_for_xml_response_status import RootTypeForXMLResponseStatus
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: RootTypeForXMLDeviceInfo,
) -> Dict[str, Any]:
    url = "{}/ISAPI/System/deviceInfo".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "put",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "data": xmltodict.unparse(json_json_body),
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[RootTypeForXMLResponseStatus]:
    if response.status_code == HTTPStatus.OK:
        response_200 = RootTypeForXMLResponseStatus.from_dict(xmltodict.parse(response.text))

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[RootTypeForXMLResponseStatus]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: RootTypeForXMLDeviceInfo,
) -> Response[RootTypeForXMLResponseStatus]:
    """Set the device information.

    Args:
        json_body (RootTypeForXMLDeviceInfo): XML message about device information Example:
            {'DeviceInfo': {'deviceName': '', 'deviceID': '', 'deviceDescription': '',
            'deviceLocation': '', 'deviceStatus': '', 'DetailAbnormalStatus': {'hardDiskFull': {},
            'hardDiskError': {}, 'ethernetBroken': {}, 'ipaddrConflict': {}, 'illegalAccess': {},
            'recordError': {}, 'raidLogicDiskError': {}, 'spareWorkDeviceError': {}}, 'systemContact':
            '', 'model': '', 'serialNumber': '', 'macAddress': '', 'firmwareVersion': '',
            'firmwareReleasedDate': '', 'bootVersion': '', 'bootReleasedDate': '', 'hardwareVersion':
            '', 'encoderVersion': '', 'encoderReleasedDate': '', 'decoderVersion': '',
            'decoderReleasedDate': '', 'softwareVersion': '', 'capacity': '', 'usedCapacity': '',
            'deviceType': '', 'telecontrolID': '', 'supportBeep': '', 'supportVideoLoss': '',
            'firmwareVersionInfo': '', 'actualFloorNum': '', 'subChannelEnabled': '',
            'thrChannelEnabled': '', 'radarVersion': '', 'cameraModuleVersion': '', 'mainversion': '',
            'subversion': '', 'upgradeversion': '', 'customizeversion': '', 'companyName': '',
            'copyright': '', 'systemName': '', 'systemStatus': '', 'isLeaderDevice': '',
            'clusterVersion': '', 'customizedInfo': '', 'localZoneNum': '', 'alarmOutNum': '',
            'distanceResolution': '', 'angleResolution': '', 'speedResolution': '', 'detectDistance':
            '', 'languageType': '', 'relayNum': '', 'electroLockNum': '', 'RS485Num': '',
            'powerOnMode': '', 'DockStation': {'Platform': {'type': '', 'ip': '', 'port': '',
            'userName': '', 'password': ''}, 'centralStorageBackupEnabled': ''}, 'webVersion': '',
            'deviceRFProgramVersion': '', 'securityModuleSerialNo': '', 'securityModuleVersion': '',
            'securityChipVersion': '', 'securityModuleKeyVersion': '', 'UIDLampRecognition':
            {'enabled': ''}, 'bootTime': '', 'ZigBeeVersion': {'@min': '0', '@max': '16'},
            'R3Version': {'@min': '0', '@max': '16'}, 'RxVersion': {'@min': '0', '@max': '16'},
            'bspVersion': '', 'dspVersion': '', 'localUIVersion': '', 'isResetDeviceLanguage':
            {'@_text': 'false'}, '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForXMLResponseStatus]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = client._api.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    json_body: RootTypeForXMLDeviceInfo,
) -> Optional[RootTypeForXMLResponseStatus]:
    """Set the device information.

    Args:
        json_body (RootTypeForXMLDeviceInfo): XML message about device information Example:
            {'DeviceInfo': {'deviceName': '', 'deviceID': '', 'deviceDescription': '',
            'deviceLocation': '', 'deviceStatus': '', 'DetailAbnormalStatus': {'hardDiskFull': {},
            'hardDiskError': {}, 'ethernetBroken': {}, 'ipaddrConflict': {}, 'illegalAccess': {},
            'recordError': {}, 'raidLogicDiskError': {}, 'spareWorkDeviceError': {}}, 'systemContact':
            '', 'model': '', 'serialNumber': '', 'macAddress': '', 'firmwareVersion': '',
            'firmwareReleasedDate': '', 'bootVersion': '', 'bootReleasedDate': '', 'hardwareVersion':
            '', 'encoderVersion': '', 'encoderReleasedDate': '', 'decoderVersion': '',
            'decoderReleasedDate': '', 'softwareVersion': '', 'capacity': '', 'usedCapacity': '',
            'deviceType': '', 'telecontrolID': '', 'supportBeep': '', 'supportVideoLoss': '',
            'firmwareVersionInfo': '', 'actualFloorNum': '', 'subChannelEnabled': '',
            'thrChannelEnabled': '', 'radarVersion': '', 'cameraModuleVersion': '', 'mainversion': '',
            'subversion': '', 'upgradeversion': '', 'customizeversion': '', 'companyName': '',
            'copyright': '', 'systemName': '', 'systemStatus': '', 'isLeaderDevice': '',
            'clusterVersion': '', 'customizedInfo': '', 'localZoneNum': '', 'alarmOutNum': '',
            'distanceResolution': '', 'angleResolution': '', 'speedResolution': '', 'detectDistance':
            '', 'languageType': '', 'relayNum': '', 'electroLockNum': '', 'RS485Num': '',
            'powerOnMode': '', 'DockStation': {'Platform': {'type': '', 'ip': '', 'port': '',
            'userName': '', 'password': ''}, 'centralStorageBackupEnabled': ''}, 'webVersion': '',
            'deviceRFProgramVersion': '', 'securityModuleSerialNo': '', 'securityModuleVersion': '',
            'securityChipVersion': '', 'securityModuleKeyVersion': '', 'UIDLampRecognition':
            {'enabled': ''}, 'bootTime': '', 'ZigBeeVersion': {'@min': '0', '@max': '16'},
            'R3Version': {'@min': '0', '@max': '16'}, 'RxVersion': {'@min': '0', '@max': '16'},
            'bspVersion': '', 'dspVersion': '', 'localUIVersion': '', 'isResetDeviceLanguage':
            {'@_text': 'false'}, '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForXMLResponseStatus]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: RootTypeForXMLDeviceInfo,
) -> Response[RootTypeForXMLResponseStatus]:
    """Set the device information.

    Args:
        json_body (RootTypeForXMLDeviceInfo): XML message about device information Example:
            {'DeviceInfo': {'deviceName': '', 'deviceID': '', 'deviceDescription': '',
            'deviceLocation': '', 'deviceStatus': '', 'DetailAbnormalStatus': {'hardDiskFull': {},
            'hardDiskError': {}, 'ethernetBroken': {}, 'ipaddrConflict': {}, 'illegalAccess': {},
            'recordError': {}, 'raidLogicDiskError': {}, 'spareWorkDeviceError': {}}, 'systemContact':
            '', 'model': '', 'serialNumber': '', 'macAddress': '', 'firmwareVersion': '',
            'firmwareReleasedDate': '', 'bootVersion': '', 'bootReleasedDate': '', 'hardwareVersion':
            '', 'encoderVersion': '', 'encoderReleasedDate': '', 'decoderVersion': '',
            'decoderReleasedDate': '', 'softwareVersion': '', 'capacity': '', 'usedCapacity': '',
            'deviceType': '', 'telecontrolID': '', 'supportBeep': '', 'supportVideoLoss': '',
            'firmwareVersionInfo': '', 'actualFloorNum': '', 'subChannelEnabled': '',
            'thrChannelEnabled': '', 'radarVersion': '', 'cameraModuleVersion': '', 'mainversion': '',
            'subversion': '', 'upgradeversion': '', 'customizeversion': '', 'companyName': '',
            'copyright': '', 'systemName': '', 'systemStatus': '', 'isLeaderDevice': '',
            'clusterVersion': '', 'customizedInfo': '', 'localZoneNum': '', 'alarmOutNum': '',
            'distanceResolution': '', 'angleResolution': '', 'speedResolution': '', 'detectDistance':
            '', 'languageType': '', 'relayNum': '', 'electroLockNum': '', 'RS485Num': '',
            'powerOnMode': '', 'DockStation': {'Platform': {'type': '', 'ip': '', 'port': '',
            'userName': '', 'password': ''}, 'centralStorageBackupEnabled': ''}, 'webVersion': '',
            'deviceRFProgramVersion': '', 'securityModuleSerialNo': '', 'securityModuleVersion': '',
            'securityChipVersion': '', 'securityModuleKeyVersion': '', 'UIDLampRecognition':
            {'enabled': ''}, 'bootTime': '', 'ZigBeeVersion': {'@min': '0', '@max': '16'},
            'R3Version': {'@min': '0', '@max': '16'}, 'RxVersion': {'@min': '0', '@max': '16'},
            'bspVersion': '', 'dspVersion': '', 'localUIVersion': '', 'isResetDeviceLanguage':
            {'@_text': 'false'}, '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForXMLResponseStatus]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = await client._asyncio_api.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    json_body: RootTypeForXMLDeviceInfo,
) -> Optional[RootTypeForXMLResponseStatus]:
    """Set the device information.

    Args:
        json_body (RootTypeForXMLDeviceInfo): XML message about device information Example:
            {'DeviceInfo': {'deviceName': '', 'deviceID': '', 'deviceDescription': '',
            'deviceLocation': '', 'deviceStatus': '', 'DetailAbnormalStatus': {'hardDiskFull': {},
            'hardDiskError': {}, 'ethernetBroken': {}, 'ipaddrConflict': {}, 'illegalAccess': {},
            'recordError': {}, 'raidLogicDiskError': {}, 'spareWorkDeviceError': {}}, 'systemContact':
            '', 'model': '', 'serialNumber': '', 'macAddress': '', 'firmwareVersion': '',
            'firmwareReleasedDate': '', 'bootVersion': '', 'bootReleasedDate': '', 'hardwareVersion':
            '', 'encoderVersion': '', 'encoderReleasedDate': '', 'decoderVersion': '',
            'decoderReleasedDate': '', 'softwareVersion': '', 'capacity': '', 'usedCapacity': '',
            'deviceType': '', 'telecontrolID': '', 'supportBeep': '', 'supportVideoLoss': '',
            'firmwareVersionInfo': '', 'actualFloorNum': '', 'subChannelEnabled': '',
            'thrChannelEnabled': '', 'radarVersion': '', 'cameraModuleVersion': '', 'mainversion': '',
            'subversion': '', 'upgradeversion': '', 'customizeversion': '', 'companyName': '',
            'copyright': '', 'systemName': '', 'systemStatus': '', 'isLeaderDevice': '',
            'clusterVersion': '', 'customizedInfo': '', 'localZoneNum': '', 'alarmOutNum': '',
            'distanceResolution': '', 'angleResolution': '', 'speedResolution': '', 'detectDistance':
            '', 'languageType': '', 'relayNum': '', 'electroLockNum': '', 'RS485Num': '',
            'powerOnMode': '', 'DockStation': {'Platform': {'type': '', 'ip': '', 'port': '',
            'userName': '', 'password': ''}, 'centralStorageBackupEnabled': ''}, 'webVersion': '',
            'deviceRFProgramVersion': '', 'securityModuleSerialNo': '', 'securityModuleVersion': '',
            'securityChipVersion': '', 'securityModuleKeyVersion': '', 'UIDLampRecognition':
            {'enabled': ''}, 'bootTime': '', 'ZigBeeVersion': {'@min': '0', '@max': '16'},
            'R3Version': {'@min': '0', '@max': '16'}, 'RxVersion': {'@min': '0', '@max': '16'},
            'bspVersion': '', 'dspVersion': '', 'localUIVersion': '', 'isResetDeviceLanguage':
            {'@_text': 'false'}, '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RootTypeForXMLResponseStatus]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_network_interface_network_interface_active_multicast import (
        RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast,
    )
    from ..models.root_type_for_xml_network_interface_network_interface_ethernet_port_list import (
        RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList,
    )
    from ..models.root_type_for_xml_network_interface_network_interface_mac_address import (
        RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress,
    )


T = TypeVar("T", bound="RootTypeForXMLNetworkInterfaceNetworkInterface")


@attr.s(auto_attribs=True)
class RootTypeForXMLNetworkInterfaceNetworkInterface:
    """
    Attributes:
        id (Union[Unset, str]):
        ip_address (Union[Unset, str]):
        wireless (Union[Unset, str]):
        discovery (Union[Unset, str]):
        link (Union[Unset, str]):
        default_connection (Union[Unset, str]):
        active_multicast (Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast]):
        mac_address (Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress]):
        ethernet_port_list (Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    id: Union[Unset, str] = UNSET
    ip_address: Union[Unset, str] = UNSET
    wireless: Union[Unset, str] = UNSET
    discovery: Union[Unset, str] = UNSET
    link: Union[Unset, str] = UNSET
    default_connection: Union[Unset, str] = UNSET
    active_multicast: Union[Unset, "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast"] = UNSET
    mac_address: Union[Unset, "RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress"] = UNSET
    ethernet_port_list: Union[Unset, "RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList"] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        ip_address = self.ip_address
        wireless = self.wireless
        discovery = self.discovery
        link = self.link
        default_connection = self.default_connection
        active_multicast: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.active_multicast, Unset):
            active_multicast = self.active_multicast.to_dict()

        mac_address: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mac_address, Unset):
            mac_address = self.mac_address.to_dict()

        ethernet_port_list: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ethernet_port_list, Unset):
            ethernet_port_list = self.ethernet_port_list.to_dict()

        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if ip_address is not UNSET:
            field_dict["IPAddress"] = ip_address
        if wireless is not UNSET:
            field_dict["Wireless"] = wireless
        if discovery is not UNSET:
            field_dict["Discovery"] = discovery
        if link is not UNSET:
            field_dict["Link"] = link
        if default_connection is not UNSET:
            field_dict["defaultConnection"] = default_connection
        if active_multicast is not UNSET:
            field_dict["ActiveMulticast"] = active_multicast
        if mac_address is not UNSET:
            field_dict["macAddress"] = mac_address
        if ethernet_port_list is not UNSET:
            field_dict["EthernetPortList"] = ethernet_port_list
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_network_interface_network_interface_active_multicast import (
            RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast,
        )
        from ..models.root_type_for_xml_network_interface_network_interface_ethernet_port_list import (
            RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList,
        )
        from ..models.root_type_for_xml_network_interface_network_interface_mac_address import (
            RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress,
        )

        d = src_dict.copy()
        id = d.pop("id", UNSET)

        ip_address = d.pop("IPAddress", UNSET)

        wireless = d.pop("Wireless", UNSET)

        discovery = d.pop("Discovery", UNSET)

        link = d.pop("Link", UNSET)

        default_connection = d.pop("defaultConnection", UNSET)

        _active_multicast = d.pop("ActiveMulticast", UNSET)
        active_multicast: Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast]
        if isinstance(_active_multicast, Unset):
            active_multicast = UNSET
        else:
            active_multicast = RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast.from_dict(
                _active_multicast
            )

        _mac_address = d.pop("macAddress", UNSET)
        mac_address: Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress]
        if isinstance(_mac_address, Unset):
            mac_address = UNSET
        else:
            mac_address = RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress.from_dict(_mac_address)

        _ethernet_port_list = d.pop("EthernetPortList", UNSET)
        ethernet_port_list: Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList]
        if isinstance(_ethernet_port_list, Unset):
            ethernet_port_list = UNSET
        else:
            ethernet_port_list = RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList.from_dict(
                _ethernet_port_list
            )

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_network_interface_network_interface = cls(
            id=id,
            ip_address=ip_address,
            wireless=wireless,
            discovery=discovery,
            link=link,
            default_connection=default_connection,
            active_multicast=active_multicast,
            mac_address=mac_address,
            ethernet_port_list=ethernet_port_list,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_network_interface_network_interface.additional_properties = d
        return root_type_for_xml_network_interface_network_interface

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from urllib.parse import urlparse
import cv2
import numpy as np

from hikvision_isapi_cli.client import Client


class RtspClient:
    def __init__(self, client: Client, rtsp_port: int, path: str) -> None:
        """
        Initialize the RtspClient class.

        :param client: A `Client` object containing the credentials for the RTSP stream.
        :param rtsp_port: The RTSP port of the stream.
        :param path: The path of the stream.
        """

        self.client = client
        self.rtsp_port = rtsp_port
        self.path = path
        self.host = urlparse(client.base_url).hostname
        self.stream_url = (
            f"rtsp://{client.username}:{client.password}@{self.host}:{rtsp_port}/{path}"
        )
        self.cap = cv2.VideoCapture(self.stream_url)
        self.cap.set(cv2.CAP_PROP_BUFFERSIZE, 60)
        self.cap.set(cv2.CAP_PROP_FOURCC, cv2.VideoWriter_fourcc(*"H264"))

    def get_snapshot(self) -> bytes:
        """
        Capture a snapshot from the RTSP stream and return the binary data of the image.

        :return: The binary data of the image, or None if the frame cannot be read.
        """

        ret, frame = self.cap.read()
        if ret:
            # Encode the image as JPEG
            _, img_encoded = cv2.imencode(".jpg", frame)
            self.release()
            # Return the binary data
            return img_encoded.tobytes()
        else:
            # Return None if the frame cannot be read
            return None

    def release(self):
        """
        Release the RTSP stream.
        """

        self.cap.release()

    def stream_url(self) -> str:
        """
        The RTSP stream string.
        """

        return self.stream_url



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_transport_control_protocol_list_control_protocol_item import (
        RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelTransportControlProtocolList")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelTransportControlProtocolList:
    """
    Attributes:
        control_protocol (Union[Unset,
            List['RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem']]):
    """

    control_protocol: Union[
        Unset, List["RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem"]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        control_protocol: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.control_protocol, Unset):
            control_protocol = []
            for control_protocol_item_data in self.control_protocol:
                control_protocol_item = control_protocol_item_data.to_dict()

                control_protocol.append(control_protocol_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if control_protocol is not UNSET:
            field_dict["ControlProtocol"] = control_protocol

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_transport_control_protocol_list_control_protocol_item import (
            RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem,
        )

        d = src_dict.copy()
        control_protocol = []
        _control_protocol = d.pop("ControlProtocol", UNSET)
        for control_protocol_item_data in _control_protocol or []:
            control_protocol_item = (
                RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem.from_dict(
                    control_protocol_item_data
                )
            )

            control_protocol.append(control_protocol_item)

        root_type_for_xml_streaming_channel_transport_control_protocol_list = cls(
            control_protocol=control_protocol,
        )

        root_type_for_xml_streaming_channel_transport_control_protocol_list.additional_properties = d
        return root_type_for_xml_streaming_channel_transport_control_protocol_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_user_check_user_check import RootTypeForXMLUserCheckUserCheck


T = TypeVar("T", bound="RootTypeForXMLUserCheck")


@attr.s(auto_attribs=True)
class RootTypeForXMLUserCheck:
    """userCheck message in XML format

    Example:
        {'userCheck': {'statusValue': '', 'statusString': '', 'isDefaultPassword': '', 'isRiskPassword': '',
            'isActivated': '', 'lockStatus': '', 'unlockTime': '', 'retryLoginTime': '', '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        user_check (Union[Unset, RootTypeForXMLUserCheckUserCheck]):
    """

    user_check: Union[Unset, "RootTypeForXMLUserCheckUserCheck"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_check: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.user_check, Unset):
            user_check = self.user_check.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if user_check is not UNSET:
            field_dict["userCheck"] = user_check

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_user_check_user_check import RootTypeForXMLUserCheckUserCheck

        d = src_dict.copy()
        _user_check = d.pop("userCheck", UNSET)
        user_check: Union[Unset, RootTypeForXMLUserCheckUserCheck]
        if isinstance(_user_check, Unset):
            user_check = UNSET
        else:
            user_check = RootTypeForXMLUserCheckUserCheck.from_dict(_user_check)

        root_type_for_xml_user_check = cls(
            user_check=user_check,
        )

        root_type_for_xml_user_check.additional_properties = d
        return root_type_for_xml_user_check

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Dict

import httpx


class Client(object):
    """A Client which has been authenticated with Digest Auth"""

    """
        Attributes:
        base_url: The base URL for the API, all requests are made to a relative path to this URL
        username: The username for the API
        password: The password for the API
        cookies: A dictionary of cookies to be sent with every request
        headers: A dictionary of headers to be sent with every request
        timeout: The maximum amount of a time in seconds a request can take. API functions will raise
            httpx.TimeoutException if this is exceeded.
        verify_ssl: Whether or not to verify the SSL certificate of the API server. This should be True in production,
            but can be set to False for testing purposes.
        raise_on_unexpected_status: Whether or not to raise an errors.UnexpectedStatus if the API returns a
            status code that was not documented in the source OpenAPI document.
    """

    def __init__(
        self,
        base_url: str,
        username: str,
        password: str,
        cookies: Dict[str, str] = {},
        headers: Dict[str, str] = {},
        timeout: float = 30,
        verify_ssl: bool = True,
        raise_on_unexpected_status: bool = False,
        keepalive_expiry: float = 30,
    ) -> None:

        self.base_url = base_url
        self.cookies = cookies
        self.headers = headers
        self.timeout = timeout
        self.verify_ssl = verify_ssl
        self.raise_on_unexpected_status = raise_on_unexpected_status
        self.cookies = cookies
        self.username = username
        self.password = password
        self.keepalive_expiry = keepalive_expiry

        limits = httpx.Limits(keepalive_expiry=keepalive_expiry)
        self._api = httpx.Client(limits=limits, verify=verify_ssl, auth=httpx.DigestAuth(username, password))
        self._asyncio_api = httpx.AsyncClient(
            limits=limits, verify=verify_ssl, auth=httpx.DigestAuth(username, password)
        )

    def get_headers(self) -> Dict[str, str]:
        """Get headers to be used in all endpoints"""
        return {**self.headers}

    def get_cookies(self) -> Dict[str, str]:
        """Get cookies to be used in all endpoints"""
        return {**self.cookies}

    def get_timeout(self) -> float:
        """Get timeout to be used in all endpoints"""
        return self.timeout



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_cap_access_control_access_control_employee_no_info_character_type import (
        RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType,
    )
    from ..models.root_type_for_xml_cap_access_control_access_control_employee_no_info_employee_no import (
        RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo,
    )
    from ..models.root_type_for_xml_cap_access_control_access_control_employee_no_info_is_support_compress import (
        RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress,
    )


T = TypeVar("T", bound="RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfo")


@attr.s(auto_attribs=True)
class RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfo:
    """
    Attributes:
        employee_no (Union[Unset, RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo]):
        character_type (Union[Unset, RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType]):
        is_support_compress (Union[Unset, RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress]):
    """

    employee_no: Union[Unset, "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo"] = UNSET
    character_type: Union[Unset, "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType"] = UNSET
    is_support_compress: Union[
        Unset, "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        employee_no: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.employee_no, Unset):
            employee_no = self.employee_no.to_dict()

        character_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.character_type, Unset):
            character_type = self.character_type.to_dict()

        is_support_compress: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.is_support_compress, Unset):
            is_support_compress = self.is_support_compress.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if employee_no is not UNSET:
            field_dict["employeeNo"] = employee_no
        if character_type is not UNSET:
            field_dict["characterType"] = character_type
        if is_support_compress is not UNSET:
            field_dict["isSupportCompress"] = is_support_compress

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_cap_access_control_access_control_employee_no_info_character_type import (
            RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType,
        )
        from ..models.root_type_for_xml_cap_access_control_access_control_employee_no_info_employee_no import (
            RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo,
        )
        from ..models.root_type_for_xml_cap_access_control_access_control_employee_no_info_is_support_compress import (
            RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress,
        )

        d = src_dict.copy()
        _employee_no = d.pop("employeeNo", UNSET)
        employee_no: Union[Unset, RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo]
        if isinstance(_employee_no, Unset):
            employee_no = UNSET
        else:
            employee_no = RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo.from_dict(_employee_no)

        _character_type = d.pop("characterType", UNSET)
        character_type: Union[Unset, RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType]
        if isinstance(_character_type, Unset):
            character_type = UNSET
        else:
            character_type = RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType.from_dict(
                _character_type
            )

        _is_support_compress = d.pop("isSupportCompress", UNSET)
        is_support_compress: Union[Unset, RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress]
        if isinstance(_is_support_compress, Unset):
            is_support_compress = UNSET
        else:
            is_support_compress = RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress.from_dict(
                _is_support_compress
            )

        root_type_for_xml_cap_access_control_access_control_employee_no_info = cls(
            employee_no=employee_no,
            character_type=character_type,
            is_support_compress=is_support_compress,
        )

        root_type_for_xml_cap_access_control_access_control_employee_no_info.additional_properties = d
        return root_type_for_xml_cap_access_control_access_control_employee_no_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_network_interface_network_interface_active_multicast_port import (
        RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort,
    )
    from ..models.root_type_for_xml_network_interface_network_interface_active_multicast_stream_id import (
        RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID,
    )


T = TypeVar("T", bound="RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast")


@attr.s(auto_attribs=True)
class RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast:
    """
    Attributes:
        enabled (Union[Unset, str]):
        stream_id (Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID]):
        ip_v4_address (Union[Unset, str]):
        ip_v6_address (Union[Unset, str]):
        port (Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort]):
    """

    enabled: Union[Unset, str] = UNSET
    stream_id: Union[Unset, "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID"] = UNSET
    ip_v4_address: Union[Unset, str] = UNSET
    ip_v6_address: Union[Unset, str] = UNSET
    port: Union[Unset, "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        stream_id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.stream_id, Unset):
            stream_id = self.stream_id.to_dict()

        ip_v4_address = self.ip_v4_address
        ip_v6_address = self.ip_v6_address
        port: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.port, Unset):
            port = self.port.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if stream_id is not UNSET:
            field_dict["streamID"] = stream_id
        if ip_v4_address is not UNSET:
            field_dict["ipV4Address"] = ip_v4_address
        if ip_v6_address is not UNSET:
            field_dict["ipV6Address"] = ip_v6_address
        if port is not UNSET:
            field_dict["port"] = port

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_network_interface_network_interface_active_multicast_port import (
            RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort,
        )
        from ..models.root_type_for_xml_network_interface_network_interface_active_multicast_stream_id import (
            RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID,
        )

        d = src_dict.copy()
        enabled = d.pop("enabled", UNSET)

        _stream_id = d.pop("streamID", UNSET)
        stream_id: Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID]
        if isinstance(_stream_id, Unset):
            stream_id = UNSET
        else:
            stream_id = RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID.from_dict(_stream_id)

        ip_v4_address = d.pop("ipV4Address", UNSET)

        ip_v6_address = d.pop("ipV6Address", UNSET)

        _port = d.pop("port", UNSET)
        port: Union[Unset, RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort]
        if isinstance(_port, Unset):
            port = UNSET
        else:
            port = RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort.from_dict(_port)

        root_type_for_xml_network_interface_network_interface_active_multicast = cls(
            enabled=enabled,
            stream_id=stream_id,
            ip_v4_address=ip_v4_address,
            ip_v6_address=ip_v6_address,
            port=port,
        )

        root_type_for_xml_network_interface_network_interface_active_multicast.additional_properties = d
        return root_type_for_xml_network_interface_network_interface_active_multicast

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel import RootTypeForXMLStreamingChannel


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelListStreamingChannelList")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelListStreamingChannelList:
    """
    Attributes:
        streaming_channel (Union[Unset, List['RootTypeForXMLStreamingChannel']]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    streaming_channel: Union[Unset, List["RootTypeForXMLStreamingChannel"]] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        streaming_channel: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.streaming_channel, Unset):
            streaming_channel = []
            for streaming_channel_item_data in self.streaming_channel:
                streaming_channel_item = streaming_channel_item_data.to_dict()

                streaming_channel.append(streaming_channel_item)

        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if streaming_channel is not UNSET:
            field_dict["StreamingChannel"] = streaming_channel
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel import RootTypeForXMLStreamingChannel

        d = src_dict.copy()
        streaming_channel = []
        _streaming_channel = d.pop("StreamingChannel", UNSET)
        for streaming_channel_item_data in _streaming_channel or []:
            streaming_channel_item = RootTypeForXMLStreamingChannel.from_dict(streaming_channel_item_data)

            streaming_channel.append(streaming_channel_item)

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_streaming_channel_list_streaming_channel_list = cls(
            streaming_channel=streaming_channel,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_streaming_channel_list_streaming_channel_list.additional_properties = d
        return root_type_for_xml_streaming_channel_list_streaming_channel_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_response_status_response_status import RootTypeForXMLResponseStatusResponseStatus


T = TypeVar("T", bound="RootTypeForXMLResponseStatus")


@attr.s(auto_attribs=True)
class RootTypeForXMLResponseStatus:
    """ResponseStatus message in XML format

    Example:
        {'ResponseStatus': {'@version': '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema', 'requestURL': '',
            'statusCode': '', 'statusString': '', 'subStatusCode': ''}}

    Attributes:
        response_status (Union[Unset, RootTypeForXMLResponseStatusResponseStatus]):
    """

    response_status: Union[Unset, "RootTypeForXMLResponseStatusResponseStatus"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        response_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.response_status, Unset):
            response_status = self.response_status.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if response_status is not UNSET:
            field_dict["ResponseStatus"] = response_status

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_response_status_response_status import (
            RootTypeForXMLResponseStatusResponseStatus,
        )

        d = src_dict.copy()
        _response_status = d.pop("ResponseStatus", UNSET)
        response_status: Union[Unset, RootTypeForXMLResponseStatusResponseStatus]
        if isinstance(_response_status, Unset):
            response_status = UNSET
        else:
            response_status = RootTypeForXMLResponseStatusResponseStatus.from_dict(_response_status)

        root_type_for_xml_response_status = cls(
            response_status=response_status,
        )

        root_type_for_xml_response_status.additional_properties = d
        return root_type_for_xml_response_status

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RootTypeForXMLDeviceInfoDeviceInfoRxVersion")


@attr.s(auto_attribs=True)
class RootTypeForXMLDeviceInfoDeviceInfoRxVersion:
    """
    Attributes:
        min_ (Union[Unset, str]):
        max_ (Union[Unset, str]):
    """

    min_: Union[Unset, str] = UNSET
    max_: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        min_ = self.min_
        max_ = self.max_

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if min_ is not UNSET:
            field_dict["@min"] = min_
        if max_ is not UNSET:
            field_dict["@max"] = max_

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        min_ = d.pop("@min", UNSET)

        max_ = d.pop("@max", UNSET)

        root_type_for_xml_device_info_device_info_rx_version = cls(
            min_=min_,
            max_=max_,
        )

        root_type_for_xml_device_info_device_info_rx_version.additional_properties = d
        return root_type_for_xml_device_info_device_info_rx_version

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_ethernet_broken import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken,
    )
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_error import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError,
    )
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_full import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull,
    )
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_illegal_access import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess,
    )
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_ipaddr_conflict import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict,
    )
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_raid_logic_disk_error import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError,
    )
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_record_error import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError,
    )
    from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_spare_work_device_error import (
        RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError,
    )


T = TypeVar("T", bound="RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus")


@attr.s(auto_attribs=True)
class RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus:
    """
    Attributes:
        hard_disk_full (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull]):
        hard_disk_error (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError]):
        ethernet_broken (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken]):
        ipaddr_conflict (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict]):
        illegal_access (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess]):
        record_error (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError]):
        raid_logic_disk_error (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError]):
        spare_work_device_error (Union[Unset,
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError]):
    """

    hard_disk_full: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull"] = UNSET
    hard_disk_error: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError"] = UNSET
    ethernet_broken: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken"] = UNSET
    ipaddr_conflict: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict"] = UNSET
    illegal_access: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess"] = UNSET
    record_error: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError"] = UNSET
    raid_logic_disk_error: Union[
        Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError"
    ] = UNSET
    spare_work_device_error: Union[
        Unset, "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        hard_disk_full: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.hard_disk_full, Unset):
            hard_disk_full = self.hard_disk_full.to_dict()

        hard_disk_error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.hard_disk_error, Unset):
            hard_disk_error = self.hard_disk_error.to_dict()

        ethernet_broken: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ethernet_broken, Unset):
            ethernet_broken = self.ethernet_broken.to_dict()

        ipaddr_conflict: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ipaddr_conflict, Unset):
            ipaddr_conflict = self.ipaddr_conflict.to_dict()

        illegal_access: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.illegal_access, Unset):
            illegal_access = self.illegal_access.to_dict()

        record_error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.record_error, Unset):
            record_error = self.record_error.to_dict()

        raid_logic_disk_error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.raid_logic_disk_error, Unset):
            raid_logic_disk_error = self.raid_logic_disk_error.to_dict()

        spare_work_device_error: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.spare_work_device_error, Unset):
            spare_work_device_error = self.spare_work_device_error.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if hard_disk_full is not UNSET:
            field_dict["hardDiskFull"] = hard_disk_full
        if hard_disk_error is not UNSET:
            field_dict["hardDiskError"] = hard_disk_error
        if ethernet_broken is not UNSET:
            field_dict["ethernetBroken"] = ethernet_broken
        if ipaddr_conflict is not UNSET:
            field_dict["ipaddrConflict"] = ipaddr_conflict
        if illegal_access is not UNSET:
            field_dict["illegalAccess"] = illegal_access
        if record_error is not UNSET:
            field_dict["recordError"] = record_error
        if raid_logic_disk_error is not UNSET:
            field_dict["raidLogicDiskError"] = raid_logic_disk_error
        if spare_work_device_error is not UNSET:
            field_dict["spareWorkDeviceError"] = spare_work_device_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_ethernet_broken import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken,
        )
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_error import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError,
        )
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_full import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull,
        )
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_illegal_access import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess,
        )
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_ipaddr_conflict import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict,
        )
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_raid_logic_disk_error import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError,
        )
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_record_error import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError,
        )
        from ..models.root_type_for_xml_device_info_device_info_detail_abnormal_status_spare_work_device_error import (
            RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError,
        )

        d = src_dict.copy()
        _hard_disk_full = d.pop("hardDiskFull", UNSET)
        hard_disk_full: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull]
        if isinstance(_hard_disk_full, Unset):
            hard_disk_full = UNSET
        else:
            hard_disk_full = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull.from_dict(
                _hard_disk_full
            )

        _hard_disk_error = d.pop("hardDiskError", UNSET)
        hard_disk_error: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError]
        if isinstance(_hard_disk_error, Unset):
            hard_disk_error = UNSET
        else:
            hard_disk_error = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError.from_dict(
                _hard_disk_error
            )

        _ethernet_broken = d.pop("ethernetBroken", UNSET)
        ethernet_broken: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken]
        if isinstance(_ethernet_broken, Unset):
            ethernet_broken = UNSET
        else:
            ethernet_broken = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken.from_dict(
                _ethernet_broken
            )

        _ipaddr_conflict = d.pop("ipaddrConflict", UNSET)
        ipaddr_conflict: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict]
        if isinstance(_ipaddr_conflict, Unset):
            ipaddr_conflict = UNSET
        else:
            ipaddr_conflict = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict.from_dict(
                _ipaddr_conflict
            )

        _illegal_access = d.pop("illegalAccess", UNSET)
        illegal_access: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess]
        if isinstance(_illegal_access, Unset):
            illegal_access = UNSET
        else:
            illegal_access = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess.from_dict(
                _illegal_access
            )

        _record_error = d.pop("recordError", UNSET)
        record_error: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError]
        if isinstance(_record_error, Unset):
            record_error = UNSET
        else:
            record_error = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError.from_dict(_record_error)

        _raid_logic_disk_error = d.pop("raidLogicDiskError", UNSET)
        raid_logic_disk_error: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError]
        if isinstance(_raid_logic_disk_error, Unset):
            raid_logic_disk_error = UNSET
        else:
            raid_logic_disk_error = RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError.from_dict(
                _raid_logic_disk_error
            )

        _spare_work_device_error = d.pop("spareWorkDeviceError", UNSET)
        spare_work_device_error: Union[
            Unset, RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError
        ]
        if isinstance(_spare_work_device_error, Unset):
            spare_work_device_error = UNSET
        else:
            spare_work_device_error = (
                RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError.from_dict(
                    _spare_work_device_error
                )
            )

        root_type_for_xml_device_info_device_info_detail_abnormal_status = cls(
            hard_disk_full=hard_disk_full,
            hard_disk_error=hard_disk_error,
            ethernet_broken=ethernet_broken,
            ipaddr_conflict=ipaddr_conflict,
            illegal_access=illegal_access,
            record_error=record_error,
            raid_logic_disk_error=raid_logic_disk_error,
            spare_work_device_error=spare_work_device_error,
        )

        root_type_for_xml_device_info_device_info_detail_abnormal_status.additional_properties = d
        return root_type_for_xml_device_info_device_info_detail_abnormal_status

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_cap_access_control_access_control import RootTypeForXMLCapAccessControlAccessControl


T = TypeVar("T", bound="RootTypeForXMLCapAccessControl")


@attr.s(auto_attribs=True)
class RootTypeForXMLCapAccessControl:
    """AccessControl capability message in XML format

    Example:
        {'AccessControl': {'isSupportWiegandCfg': {}, 'isSupportModuleStatus': {}, 'isSupportSNAPConfig': {},
            'LocalController': {'isSupportLocalControllerManage': {}, 'isSupportLocalControllerControl': {}},
            'isSupportUSBManage': {}, 'isSupportIdentityTerminal': {}, 'isSupportDepartmentParam': {},
            'isSupportSchedulePlan': {}, 'isSupportAttendanceRule': {}, 'isSupportOrdinaryClass': {},
            'isSupportWorkingClass': {}, 'isSupportAttendanceHolidayGroup': {}, 'isSupportAttendanceHolidayPlan': {},
            'isSupportLadderControlRelay': {}, 'isSupportWiegandRuleCfg': {}, 'isSupportM1CardEncryptCfg': {},
            'isSupportDeployInfo': [{}, {}], 'isSupportSubmarineBack': {}, 'isSupportSubmarineBackHostInfo': {},
            'isSupportStartReaderInfo': {}, 'isSupportSubmarineBackReader': {}, 'isSupportServerDevice': {},
            'isSupportReaderAcrossHost': {}, 'isSupportClearCardRecord': {}, 'isSupportSubmarineBackMode': {},
            'isSupportClearSubmarineBack': {}, 'isSupportRemoteControlDoor': {}, 'isSupportUserInfo': '', 'EmployeeNoInfo':
            {'employeeNo': {'@min': '', '@max': ''}, 'characterType': {'@opt': 'any,number'}, 'isSupportCompress': {}},
            'isSupportCardInfo': '', 'isSupportUserInfoDetailDelete': '', 'isSupportAuthCodeInfo': {},
            'isSupportFingerPrintCfg': {}, 'isSupportFingerPrintDelete': {}, 'isSupportCaptureFingerPrint': {},
            'isSupportDoorStatusWeekPlanCfg': {}, 'isSupportVerifyWeekPlanCfg': {}, 'isSupportCardRightWeekPlanCfg': {},
            'isSupportDoorStatusHolidayPlanCfg': {}, 'isSupportVerifyHolidayPlanCfg': {},
            'isSupportCardRightHolidayPlanCfg': {}, 'isSupportDoorStatusHolidayGroupCfg': {},
            'isSupportVerifyHolidayGroupCfg': {}, 'isSupportUserRightHolidayGroupCfg': {},
            'isSupportDoorStatusPlanTemplate': {}, 'isSupportVerifyPlanTemplate': {}, 'isSupportUserRightPlanTemplate': {},
            'isSupportDoorStatusPlan': {}, 'isSupportCardReaderPlan': {}, 'isSupportClearPlansCfg': {},
            'isSupportRemoteControlBuzzer': {}, 'isSupportEventCardNoList': {}, 'isSupportEventCardLinkageCfg': {},
            'isSupportClearEventCardLinkageCfg': {}, 'isSupportAcsEvent': {}, 'isSupportAcsEventTotalNum': {},
            'isSupportEventOptimizationCfg': {}, 'isSupportAcsWorkStatus': {}, 'isSupportDoorCfg': {},
            'isSupportCardReaderCfg': {}, 'isSupportAcsCfg': {}, 'isSupportGroupCfg': {}, 'isSupportClearGroupCfg': {},
            'isSupportMultiCardCfg': {}, 'isSupportMultiDoorInterLockCfg': {}, 'isSupportAntiSneakCfg': {},
            'isSupportCardReaderAntiSneakCfg': {}, 'isSupportClearAntiSneakCfg': {}, 'isSupportClearAntiSneak': {},
            'isSupportSmsRelativeParam': {}, 'isSupportPhoneDoorRightCfg': {}, 'isSupportOSDPStatus': {},
            'isSupportOSDPModify': {}, 'isSupportLogModeCfg': {}, 'FactoryReset': {'isSupportFactoryReset': '', 'mode':
            {'@opt': 'full,basic,part'}}, 'isSupportNFCCfg': '', 'isSupportRFCardCfg': '', 'isSupportCaptureFace': {},
            'isSupportCaptureInfraredFace': {}, 'isSupportFaceRecognizeMode': {}, 'isSupportRemoteControlPWChcek': {},
            'isSupportRemoteControlPWCfg': {}, 'isSupportAttendanceStatusModeCfg': {}, 'isSupportAttendanceStatusRuleCfg':
            {}, 'isSupportCaptureCardInfo': {}, 'isSupportCaptureIDInfo': {}, 'isSupportCaptureRule': {},
            'isSupportCapturePresetParam': {}, 'isSupportOfflineCapture': {}, 'isSupportCardOperations': {},
            'isSupportRightControllerAudio': {}, 'isSupportChannelControllerCfg': {}, 'isSupportGateDialAndInfo': {},
            'isSupportGateStatus': {}, 'isSupportGateIRStatus': {}, 'isSupportGateRelatedPartsStatus': {},
            'isSupportChannelControllerAlarmLinkage': {}, 'isSupportChannelControllerAlarmOut': {},
            'isSupportChannelControllerAlarmOutControl': {}, 'isSupportChannelControllerTypeCfg': {}, 'isSupportTTSText':
            '', 'isSupportIDBlackListCfg': '', 'isSupportUserDataImport': '', 'isSupportUserDataExport': '',
            'isSupportMaintenanceDataExport': '', 'isSupportLockTypeCfg': '', '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        access_control (Union[Unset, RootTypeForXMLCapAccessControlAccessControl]):
    """

    access_control: Union[Unset, "RootTypeForXMLCapAccessControlAccessControl"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        access_control: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.access_control, Unset):
            access_control = self.access_control.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if access_control is not UNSET:
            field_dict["AccessControl"] = access_control

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_cap_access_control_access_control import (
            RootTypeForXMLCapAccessControlAccessControl,
        )

        d = src_dict.copy()
        _access_control = d.pop("AccessControl", UNSET)
        access_control: Union[Unset, RootTypeForXMLCapAccessControlAccessControl]
        if isinstance(_access_control, Unset):
            access_control = UNSET
        else:
            access_control = RootTypeForXMLCapAccessControlAccessControl.from_dict(_access_control)

        root_type_for_xml_cap_access_control = cls(
            access_control=access_control,
        )

        root_type_for_xml_cap_access_control.additional_properties = d
        return root_type_for_xml_cap_access_control

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_list_streaming_channel_list import (
        RootTypeForXMLStreamingChannelListStreamingChannelList,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelList")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelList:
    """StreamingChannelList message in XML format

    Example:
        {'StreamingChannelList': {'StreamingChannel': [], '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        streaming_channel_list (Union[Unset, RootTypeForXMLStreamingChannelListStreamingChannelList]):
    """

    streaming_channel_list: Union[Unset, "RootTypeForXMLStreamingChannelListStreamingChannelList"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        streaming_channel_list: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.streaming_channel_list, Unset):
            streaming_channel_list = self.streaming_channel_list.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if streaming_channel_list is not UNSET:
            field_dict["StreamingChannelList"] = streaming_channel_list

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_list_streaming_channel_list import (
            RootTypeForXMLStreamingChannelListStreamingChannelList,
        )

        d = src_dict.copy()
        _streaming_channel_list = d.pop("StreamingChannelList", UNSET)
        streaming_channel_list: Union[Unset, RootTypeForXMLStreamingChannelListStreamingChannelList]
        if isinstance(_streaming_channel_list, Unset):
            streaming_channel_list = UNSET
        else:
            streaming_channel_list = RootTypeForXMLStreamingChannelListStreamingChannelList.from_dict(
                _streaming_channel_list
            )

        root_type_for_xml_streaming_channel_list = cls(
            streaming_channel_list=streaming_channel_list,
        )

        root_type_for_xml_streaming_channel_list.additional_properties = d
        return root_type_for_xml_streaming_channel_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform")


@attr.s(auto_attribs=True)
class RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform:
    """
    Attributes:
        type (Union[Unset, str]):
        ip (Union[Unset, str]):
        port (Union[Unset, str]):
        user_name (Union[Unset, str]):
        password (Union[Unset, str]):
    """

    type: Union[Unset, str] = UNSET
    ip: Union[Unset, str] = UNSET
    port: Union[Unset, str] = UNSET
    user_name: Union[Unset, str] = UNSET
    password: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type
        ip = self.ip
        port = self.port
        user_name = self.user_name
        password = self.password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type is not UNSET:
            field_dict["type"] = type
        if ip is not UNSET:
            field_dict["ip"] = ip
        if port is not UNSET:
            field_dict["port"] = port
        if user_name is not UNSET:
            field_dict["userName"] = user_name
        if password is not UNSET:
            field_dict["password"] = password

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = d.pop("type", UNSET)

        ip = d.pop("ip", UNSET)

        port = d.pop("port", UNSET)

        user_name = d.pop("userName", UNSET)

        password = d.pop("password", UNSET)

        root_type_for_xml_device_info_device_info_dock_station_platform = cls(
            type=type,
            ip=ip,
            port=port,
            user_name=user_name,
            password=password,
        )

        root_type_for_xml_device_info_device_info_dock_station_platform.additional_properties = d
        return root_type_for_xml_device_info_device_info_dock_station_platform

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RootTypeForXMLSessionLoginSessionLogin")


@attr.s(auto_attribs=True)
class RootTypeForXMLSessionLoginSessionLogin:
    """
    Attributes:
        user_name (Union[Unset, str]):
        password (Union[Unset, str]):
        session_id (Union[Unset, str]):
        is_support_session_tag (Union[Unset, str]):
        is_session_id_valid_long_term (Union[Unset, str]):
        session_id_version (Union[Unset, str]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    user_name: Union[Unset, str] = UNSET
    password: Union[Unset, str] = UNSET
    session_id: Union[Unset, str] = UNSET
    is_support_session_tag: Union[Unset, str] = UNSET
    is_session_id_valid_long_term: Union[Unset, str] = UNSET
    session_id_version: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_name = self.user_name
        password = self.password
        session_id = self.session_id
        is_support_session_tag = self.is_support_session_tag
        is_session_id_valid_long_term = self.is_session_id_valid_long_term
        session_id_version = self.session_id_version
        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if user_name is not UNSET:
            field_dict["userName"] = user_name
        if password is not UNSET:
            field_dict["password"] = password
        if session_id is not UNSET:
            field_dict["sessionID"] = session_id
        if is_support_session_tag is not UNSET:
            field_dict["isSupportSessionTag"] = is_support_session_tag
        if is_session_id_valid_long_term is not UNSET:
            field_dict["isSessionIDValidLongTerm"] = is_session_id_valid_long_term
        if session_id_version is not UNSET:
            field_dict["sessionIDVersion"] = session_id_version
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_name = d.pop("userName", UNSET)

        password = d.pop("password", UNSET)

        session_id = d.pop("sessionID", UNSET)

        is_support_session_tag = d.pop("isSupportSessionTag", UNSET)

        is_session_id_valid_long_term = d.pop("isSessionIDValidLongTerm", UNSET)

        session_id_version = d.pop("sessionIDVersion", UNSET)

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_session_login_session_login = cls(
            user_name=user_name,
            password=password,
            session_id=session_id,
            is_support_session_tag=is_support_session_tag,
            is_session_id_valid_long_term=is_session_id_valid_long_term,
            session_id_version=session_id_version,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_session_login_session_login.additional_properties = d
        return root_type_for_xml_session_login_session_login

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="RootTypeForXMLSessionLoginResponseSessionLogin")


@attr.s(auto_attribs=True)
class RootTypeForXMLSessionLoginResponseSessionLogin:
    """
    Attributes:
        status_value (Union[Unset, str]):
        status_string (Union[Unset, str]):
        is_default_password (Union[Unset, str]):
        is_risk_password (Union[Unset, str]):
        is_activated (Union[Unset, str]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    status_value: Union[Unset, str] = UNSET
    status_string: Union[Unset, str] = UNSET
    is_default_password: Union[Unset, str] = UNSET
    is_risk_password: Union[Unset, str] = UNSET
    is_activated: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status_value = self.status_value
        status_string = self.status_string
        is_default_password = self.is_default_password
        is_risk_password = self.is_risk_password
        is_activated = self.is_activated
        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if status_value is not UNSET:
            field_dict["statusValue"] = status_value
        if status_string is not UNSET:
            field_dict["statusString"] = status_string
        if is_default_password is not UNSET:
            field_dict["isDefaultPassword"] = is_default_password
        if is_risk_password is not UNSET:
            field_dict["isRiskPassword"] = is_risk_password
        if is_activated is not UNSET:
            field_dict["isActivated"] = is_activated
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        status_value = d.pop("statusValue", UNSET)

        status_string = d.pop("statusString", UNSET)

        is_default_password = d.pop("isDefaultPassword", UNSET)

        is_risk_password = d.pop("isRiskPassword", UNSET)

        is_activated = d.pop("isActivated", UNSET)

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_session_login_response_session_login = cls(
            status_value=status_value,
            status_string=status_string,
            is_default_password=is_default_password,
            is_risk_password=is_risk_password,
            is_activated=is_activated,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_session_login_response_session_login.additional_properties = d
        return root_type_for_xml_session_login_response_session_login

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_session_login_session_login import RootTypeForXMLSessionLoginSessionLogin


T = TypeVar("T", bound="RootTypeForXMLSessionLogin")


@attr.s(auto_attribs=True)
class RootTypeForXMLSessionLogin:
    """
    Example:
        {'SessionLogin': {'userName': 'admin', 'password': 'xxxxxxxxxxxx', 'sessionID':
            '5ab522a707187090e375dc9e07f80f48f6a2a1c4a171b501b47ea9607db57f7f', 'isSupportSessionTag': 'false',
            'isSessionIDValidLongTerm': 'false', 'sessionIDVersion': '2', '@version': '2.0', '@xmlns':
            'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        session_login (Union[Unset, RootTypeForXMLSessionLoginSessionLogin]):
    """

    session_login: Union[Unset, "RootTypeForXMLSessionLoginSessionLogin"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        session_login: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.session_login, Unset):
            session_login = self.session_login.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if session_login is not UNSET:
            field_dict["SessionLogin"] = session_login

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_session_login_session_login import RootTypeForXMLSessionLoginSessionLogin

        d = src_dict.copy()
        _session_login = d.pop("SessionLogin", UNSET)
        session_login: Union[Unset, RootTypeForXMLSessionLoginSessionLogin]
        if isinstance(_session_login, Unset):
            session_login = UNSET
        else:
            session_login = RootTypeForXMLSessionLoginSessionLogin.from_dict(_session_login)

        root_type_for_xml_session_login = cls(
            session_login=session_login,
        )

        root_type_for_xml_session_login.additional_properties = d
        return root_type_for_xml_session_login

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_video_input_channel_video_input_channel import (
        RootTypeForXMLVideoInputChannelVideoInputChannel,
    )


T = TypeVar("T", bound="RootTypeForXMLVideoInputChannel")


@attr.s(auto_attribs=True)
class RootTypeForXMLVideoInputChannel:
    """VideoInputChannel message in XML format

    Example:
        {'VideoInputChannel': {'id': {}, 'inputPort': {}, 'videoInputEnabled': {}, 'name': {}, 'videoFormat': {},
            'portType': {}, 'resDesc': {}, '@version': '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        video_input_channel (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannel]):
    """

    video_input_channel: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannel"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        video_input_channel: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_input_channel, Unset):
            video_input_channel = self.video_input_channel.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if video_input_channel is not UNSET:
            field_dict["VideoInputChannel"] = video_input_channel

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_video_input_channel_video_input_channel import (
            RootTypeForXMLVideoInputChannelVideoInputChannel,
        )

        d = src_dict.copy()
        _video_input_channel = d.pop("VideoInputChannel", UNSET)
        video_input_channel: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannel]
        if isinstance(_video_input_channel, Unset):
            video_input_channel = UNSET
        else:
            video_input_channel = RootTypeForXMLVideoInputChannelVideoInputChannel.from_dict(_video_input_channel)

        root_type_for_xml_video_input_channel = cls(
            video_input_channel=video_input_channel,
        )

        root_type_for_xml_video_input_channel.additional_properties = d
        return root_type_for_xml_video_input_channel

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_video_input_channel_video_input_channel_id import (
        RootTypeForXMLVideoInputChannelVideoInputChannelId,
    )
    from ..models.root_type_for_xml_video_input_channel_video_input_channel_input_port import (
        RootTypeForXMLVideoInputChannelVideoInputChannelInputPort,
    )
    from ..models.root_type_for_xml_video_input_channel_video_input_channel_name import (
        RootTypeForXMLVideoInputChannelVideoInputChannelName,
    )
    from ..models.root_type_for_xml_video_input_channel_video_input_channel_port_type import (
        RootTypeForXMLVideoInputChannelVideoInputChannelPortType,
    )
    from ..models.root_type_for_xml_video_input_channel_video_input_channel_res_desc import (
        RootTypeForXMLVideoInputChannelVideoInputChannelResDesc,
    )
    from ..models.root_type_for_xml_video_input_channel_video_input_channel_video_format import (
        RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat,
    )
    from ..models.root_type_for_xml_video_input_channel_video_input_channel_video_input_enabled import (
        RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled,
    )


T = TypeVar("T", bound="RootTypeForXMLVideoInputChannelVideoInputChannel")


@attr.s(auto_attribs=True)
class RootTypeForXMLVideoInputChannelVideoInputChannel:
    """
    Attributes:
        id (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelId]):
        input_port (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelInputPort]):
        video_input_enabled (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled]):
        name (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelName]):
        video_format (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat]):
        port_type (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelPortType]):
        res_desc (Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelResDesc]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    id: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannelId"] = UNSET
    input_port: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannelInputPort"] = UNSET
    video_input_enabled: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled"] = UNSET
    name: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannelName"] = UNSET
    video_format: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat"] = UNSET
    port_type: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannelPortType"] = UNSET
    res_desc: Union[Unset, "RootTypeForXMLVideoInputChannelVideoInputChannelResDesc"] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.id, Unset):
            id = self.id.to_dict()

        input_port: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.input_port, Unset):
            input_port = self.input_port.to_dict()

        video_input_enabled: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_input_enabled, Unset):
            video_input_enabled = self.video_input_enabled.to_dict()

        name: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.name, Unset):
            name = self.name.to_dict()

        video_format: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_format, Unset):
            video_format = self.video_format.to_dict()

        port_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.port_type, Unset):
            port_type = self.port_type.to_dict()

        res_desc: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.res_desc, Unset):
            res_desc = self.res_desc.to_dict()

        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if input_port is not UNSET:
            field_dict["inputPort"] = input_port
        if video_input_enabled is not UNSET:
            field_dict["videoInputEnabled"] = video_input_enabled
        if name is not UNSET:
            field_dict["name"] = name
        if video_format is not UNSET:
            field_dict["videoFormat"] = video_format
        if port_type is not UNSET:
            field_dict["portType"] = port_type
        if res_desc is not UNSET:
            field_dict["resDesc"] = res_desc
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_video_input_channel_video_input_channel_id import (
            RootTypeForXMLVideoInputChannelVideoInputChannelId,
        )
        from ..models.root_type_for_xml_video_input_channel_video_input_channel_input_port import (
            RootTypeForXMLVideoInputChannelVideoInputChannelInputPort,
        )
        from ..models.root_type_for_xml_video_input_channel_video_input_channel_name import (
            RootTypeForXMLVideoInputChannelVideoInputChannelName,
        )
        from ..models.root_type_for_xml_video_input_channel_video_input_channel_port_type import (
            RootTypeForXMLVideoInputChannelVideoInputChannelPortType,
        )
        from ..models.root_type_for_xml_video_input_channel_video_input_channel_res_desc import (
            RootTypeForXMLVideoInputChannelVideoInputChannelResDesc,
        )
        from ..models.root_type_for_xml_video_input_channel_video_input_channel_video_format import (
            RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat,
        )
        from ..models.root_type_for_xml_video_input_channel_video_input_channel_video_input_enabled import (
            RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled,
        )

        d = src_dict.copy()
        _id = d.pop("id", UNSET)
        id: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelId]
        if isinstance(_id, Unset):
            id = UNSET
        else:
            id = RootTypeForXMLVideoInputChannelVideoInputChannelId.from_dict(_id)

        _input_port = d.pop("inputPort", UNSET)
        input_port: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelInputPort]
        if isinstance(_input_port, Unset):
            input_port = UNSET
        else:
            input_port = RootTypeForXMLVideoInputChannelVideoInputChannelInputPort.from_dict(_input_port)

        _video_input_enabled = d.pop("videoInputEnabled", UNSET)
        video_input_enabled: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled]
        if isinstance(_video_input_enabled, Unset):
            video_input_enabled = UNSET
        else:
            video_input_enabled = RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled.from_dict(
                _video_input_enabled
            )

        _name = d.pop("name", UNSET)
        name: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelName]
        if isinstance(_name, Unset):
            name = UNSET
        else:
            name = RootTypeForXMLVideoInputChannelVideoInputChannelName.from_dict(_name)

        _video_format = d.pop("videoFormat", UNSET)
        video_format: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat]
        if isinstance(_video_format, Unset):
            video_format = UNSET
        else:
            video_format = RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat.from_dict(_video_format)

        _port_type = d.pop("portType", UNSET)
        port_type: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelPortType]
        if isinstance(_port_type, Unset):
            port_type = UNSET
        else:
            port_type = RootTypeForXMLVideoInputChannelVideoInputChannelPortType.from_dict(_port_type)

        _res_desc = d.pop("resDesc", UNSET)
        res_desc: Union[Unset, RootTypeForXMLVideoInputChannelVideoInputChannelResDesc]
        if isinstance(_res_desc, Unset):
            res_desc = UNSET
        else:
            res_desc = RootTypeForXMLVideoInputChannelVideoInputChannelResDesc.from_dict(_res_desc)

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_video_input_channel_video_input_channel = cls(
            id=id,
            input_port=input_port,
            video_input_enabled=video_input_enabled,
            name=name,
            video_format=video_format,
            port_type=port_type,
            res_desc=res_desc,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_video_input_channel_video_input_channel.additional_properties = d
        return root_type_for_xml_video_input_channel_video_input_channel

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_json_cap_call_status_call_status import RootTypeForJSONCapCallStatusCallStatus


T = TypeVar("T", bound="RootTypeForJSONCapCallStatus")


@attr.s(auto_attribs=True)
class RootTypeForJSONCapCallStatus:
    """JSON message about the capability of getting the call statusv

    Example:
        {'CallStatus': {'status': {'@opt': ['idle', 'ring', 'onCall']}}}

    Attributes:
        call_status (Union[Unset, RootTypeForJSONCapCallStatusCallStatus]):
    """

    call_status: Union[Unset, "RootTypeForJSONCapCallStatusCallStatus"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        call_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.call_status, Unset):
            call_status = self.call_status.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if call_status is not UNSET:
            field_dict["CallStatus"] = call_status

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_json_cap_call_status_call_status import RootTypeForJSONCapCallStatusCallStatus

        d = src_dict.copy()
        _call_status = d.pop("CallStatus", UNSET)
        call_status: Union[Unset, RootTypeForJSONCapCallStatusCallStatus]
        if isinstance(_call_status, Unset):
            call_status = UNSET
        else:
            call_status = RootTypeForJSONCapCallStatusCallStatus.from_dict(_call_status)

        root_type_for_json_cap_call_status = cls(
            call_status=call_status,
        )

        root_type_for_json_cap_call_status.additional_properties = d
        return root_type_for_json_cap_call_status

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_device_info_device_info import RootTypeForXMLDeviceInfoDeviceInfo


T = TypeVar("T", bound="RootTypeForXMLDeviceInfo")


@attr.s(auto_attribs=True)
class RootTypeForXMLDeviceInfo:
    """XML message about device information

    Example:
        {'DeviceInfo': {'deviceName': '', 'deviceID': '', 'deviceDescription': '', 'deviceLocation': '', 'deviceStatus':
            '', 'DetailAbnormalStatus': {'hardDiskFull': {}, 'hardDiskError': {}, 'ethernetBroken': {}, 'ipaddrConflict':
            {}, 'illegalAccess': {}, 'recordError': {}, 'raidLogicDiskError': {}, 'spareWorkDeviceError': {}},
            'systemContact': '', 'model': '', 'serialNumber': '', 'macAddress': '', 'firmwareVersion': '',
            'firmwareReleasedDate': '', 'bootVersion': '', 'bootReleasedDate': '', 'hardwareVersion': '', 'encoderVersion':
            '', 'encoderReleasedDate': '', 'decoderVersion': '', 'decoderReleasedDate': '', 'softwareVersion': '',
            'capacity': '', 'usedCapacity': '', 'deviceType': '', 'telecontrolID': '', 'supportBeep': '',
            'supportVideoLoss': '', 'firmwareVersionInfo': '', 'actualFloorNum': '', 'subChannelEnabled': '',
            'thrChannelEnabled': '', 'radarVersion': '', 'cameraModuleVersion': '', 'mainversion': '', 'subversion': '',
            'upgradeversion': '', 'customizeversion': '', 'companyName': '', 'copyright': '', 'systemName': '',
            'systemStatus': '', 'isLeaderDevice': '', 'clusterVersion': '', 'customizedInfo': '', 'localZoneNum': '',
            'alarmOutNum': '', 'distanceResolution': '', 'angleResolution': '', 'speedResolution': '', 'detectDistance': '',
            'languageType': '', 'relayNum': '', 'electroLockNum': '', 'RS485Num': '', 'powerOnMode': '', 'DockStation':
            {'Platform': {'type': '', 'ip': '', 'port': '', 'userName': '', 'password': ''}, 'centralStorageBackupEnabled':
            ''}, 'webVersion': '', 'deviceRFProgramVersion': '', 'securityModuleSerialNo': '', 'securityModuleVersion': '',
            'securityChipVersion': '', 'securityModuleKeyVersion': '', 'UIDLampRecognition': {'enabled': ''}, 'bootTime':
            '', 'ZigBeeVersion': {'@min': '0', '@max': '16'}, 'R3Version': {'@min': '0', '@max': '16'}, 'RxVersion':
            {'@min': '0', '@max': '16'}, 'bspVersion': '', 'dspVersion': '', 'localUIVersion': '', 'isResetDeviceLanguage':
            {'@_text': 'false'}, '@version': '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        device_info (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfo]):
    """

    device_info: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfo"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        device_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.device_info, Unset):
            device_info = self.device_info.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if device_info is not UNSET:
            field_dict["DeviceInfo"] = device_info

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_device_info_device_info import RootTypeForXMLDeviceInfoDeviceInfo

        d = src_dict.copy()
        _device_info = d.pop("DeviceInfo", UNSET)
        device_info: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfo]
        if isinstance(_device_info, Unset):
            device_info = UNSET
        else:
            device_info = RootTypeForXMLDeviceInfoDeviceInfo.from_dict(_device_info)

        root_type_for_xml_device_info = cls(
            device_info=device_info,
        )

        root_type_for_xml_device_info.additional_properties = d
        return root_type_for_xml_device_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_device_info_device_info_dock_station_platform import (
        RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform,
    )


T = TypeVar("T", bound="RootTypeForXMLDeviceInfoDeviceInfoDockStation")


@attr.s(auto_attribs=True)
class RootTypeForXMLDeviceInfoDeviceInfoDockStation:
    """
    Attributes:
        platform (Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform]):
        central_storage_backup_enabled (Union[Unset, str]):
    """

    platform: Union[Unset, "RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform"] = UNSET
    central_storage_backup_enabled: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        platform: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.platform, Unset):
            platform = self.platform.to_dict()

        central_storage_backup_enabled = self.central_storage_backup_enabled

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if platform is not UNSET:
            field_dict["Platform"] = platform
        if central_storage_backup_enabled is not UNSET:
            field_dict["centralStorageBackupEnabled"] = central_storage_backup_enabled

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_device_info_device_info_dock_station_platform import (
            RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform,
        )

        d = src_dict.copy()
        _platform = d.pop("Platform", UNSET)
        platform: Union[Unset, RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform]
        if isinstance(_platform, Unset):
            platform = UNSET
        else:
            platform = RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform.from_dict(_platform)

        central_storage_backup_enabled = d.pop("centralStorageBackupEnabled", UNSET)

        root_type_for_xml_device_info_device_info_dock_station = cls(
            platform=platform,
            central_storage_backup_enabled=central_storage_backup_enabled,
        )

        root_type_for_xml_device_info_device_info_dock_station.additional_properties = d
        return root_type_for_xml_device_info_device_info_dock_station

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
